@@ -1,5 +1,9 @@
 package Sidef::Types::Array::List {
 
+    use parent qw(
+      Sidef::Object::Object
+      );
+
     sub new {
         shift;
         bless \@_, __PACKAGE__;
