@@ -33,13 +33,18 @@ package Sidef::Types::Block::Code {
         $exec->execute_expr($self->{code});
     }
 
-    sub get_value {
-        my ($self) = @_;
-        sub {
-            if (defined($a) || defined($b)) { push @_, $a, $b }
-            elsif (defined($_)) { push @_, $_ }
-            $self->call(@_);
-        };
+    {
+        my $ref = \&UNIVERSAL::AUTOLOAD;
+
+        sub get_value {
+            my ($self) = @_;
+            sub {
+                local *UNIVERSAL::AUTOLOAD = $ref;
+                if (defined($a) || defined($b)) { push @_, $a, $b }
+                elsif (defined($_)) { push @_, $_ }
+                $self->call(@_);
+            };
+        }
     }
 
     sub copy {
@@ -151,6 +156,11 @@ package Sidef::Types::Block::Code {
     sub while {
         my ($self, $condition, $old_self) = @_;
 
+        if (exists($condition->{_special_stack_vars}) and not exists($self->{_specialized})) {
+            $self->{_specialized} = 1;
+            push @{$self->{vars}}, @{$condition->{_special_stack_vars}};
+        }
+
         while ($condition->run) {
             defined($old_self) && ($old_self->{did_while} //= 1);
             if (defined(my $res = $self->_run_code)) {
@@ -162,15 +172,33 @@ package Sidef::Types::Block::Code {
     }
 
     sub loop {
-        my ($self, $code) = @_;
+        my ($self) = @_;
 
         while (1) {
-            if (defined(my $res = $code->_run_code)) {
+            if (defined(my $res = $self->_run_code)) {
                 return $res;
             }
         }
 
-        $code;
+        $self;
+    }
+
+    sub try {
+        my ($self) = @_;
+
+        my $try = Sidef::Types::Block::Try->new();
+
+        my $error = 0;
+        local $SIG{__WARN__} = sub { $try->{type} = 'warning'; $try->{msg} = $_[0]; $error = 1 };
+        local $SIG{__DIE__}  = sub { $try->{type} = 'error';   $try->{msg} = $_[0]; $error = 1 };
+
+        $try->{val} = eval { $self->run };
+
+        if ($@ || $error) {
+            $try->{catch} = 1;
+        }
+
+        $try;
     }
 
     {
@@ -342,6 +370,7 @@ package Sidef::Types::Block::Code {
 
         my $pid = fork() // die "[FATAL ERROR]: cannot fork";
         if ($pid == 0) {
+            srand();
             Storable::store($self->run, $filename);
             exit 0;
         }
@@ -350,6 +379,22 @@ package Sidef::Types::Block::Code {
         $fork;
     }
 
+    sub pfork {
+        my ($self) = @_;
+
+        my $fork = Sidef::Types::Block::Fork->new();
+
+        my $pid = fork() // die "[FATAL ERROR]: cannot fork";
+        if ($pid == 0) {
+            srand();
+            $self->run;
+            exit 0;
+        }
+
+        $fork->{pid} = $pid;
+        $fork;
+    }
+
     sub thread {
         my ($self) = @_;
         state $x = do {
