@@ -5,6 +5,7 @@ package Sidef::Types::String::String {
 
     use parent qw(
       Sidef::Object::Object
+      Sidef::Convert::Convert
       );
 
     use overload
@@ -29,6 +30,13 @@ package Sidef::Types::String::String {
         ${$_[0]};
     }
 
+    sub to_s {
+        $_[0];
+    }
+
+    *to_str    = \&to_s;
+    *to_string = \&to_s;
+
     sub unroll_operator {
         my ($self, $operator, $arg) = @_;
         $self->to_chars->unroll_operator(
@@ -403,18 +411,6 @@ package Sidef::Types::String::String {
         $self->new(scalar CORE::reverse($self->get_value));
     }
 
-    sub say {
-        my ($self) = @_;
-        Sidef::Types::Bool::Bool->new(CORE::say($self->get_value));
-    }
-
-    *println = \&say;
-
-    sub print {
-        my ($self) = @_;
-        Sidef::Types::Bool::Bool->new(print $self->get_value);
-    }
-
     sub printf {
         my ($self, @arguments) = @_;
         Sidef::Types::Bool::Bool->new(printf $self->get_value, @arguments);
@@ -877,6 +873,29 @@ package Sidef::Types::String::String {
         $self->new(Encode::decode_utf8($self->get_value));
     }
 
+    sub _require {
+        my ($self) = @_;
+
+        my $name = $self->get_value;
+        eval { require(($name . '.pm') =~ s{::}{/}gr) };
+
+        if ($@) {
+            die substr($@, 0, rindex($@, ' at ')), "\n";
+        }
+
+        $name;
+    }
+
+    sub require {
+        my ($self) = @_;
+        Sidef::Module::OO->__NEW__(module => $self->_require);
+    }
+
+    sub frequire {
+        my ($self) = @_;
+        Sidef::Module::Func->__NEW__(module => $self->_require);
+    }
+
     sub unescape {
         my ($self) = @_;
         $self->new($self->get_value =~ s{\\(.)}{$1}grs);
